@@ -1,10 +1,9 @@
-__version__ = '0.6.5'
+__version__ = '0.8.0'
 
 
 import logging
-import os
 import sys
-from pathlib import Path
+from typing import Union
 
 from .corpora import (
     MainCorpus,
@@ -42,9 +41,7 @@ MSG_FMT = "[{asctime},{msecs:3.0f}] [{levelname}] " \
 DATE_FMT = "%d.%m.%Y %H:%M:%S"
 
 LOGGER_NAME = "rnc"
-LOG_FOLDER = Path('logs')
-LOG_FILE = LOG_FOLDER / f"{LOGGER_NAME}.log"
-os.makedirs(LOG_FOLDER, exist_ok=True)
+LOG_FILE = f"{LOGGER_NAME}.log"
 
 
 formatter = logging.Formatter(
@@ -56,7 +53,7 @@ stream_handler.setFormatter(formatter)
 
 file_handler = logging.FileHandler(
     LOG_FILE, delay=True, encoding='utf-8')
-file_handler.setLevel(logging.DEBUG)
+file_handler.setLevel(logging.CRITICAL)
 file_handler.setFormatter(formatter)
 
 logger = logging.getLogger(LOGGER_NAME)
@@ -67,9 +64,9 @@ logger.addHandler(file_handler)
 
 
 def set_handler_level(handler_class: type):
-    def wrapped(level: int or str) -> None:
+    def wrapped(level: Union[int, str]) -> None:
         try:
-            level = level.upper()
+            level = level.upper() # type: ignore
         except AttributeError:
             pass
 
@@ -88,9 +85,9 @@ set_stream_handler_level = set_handler_level(logging.StreamHandler)
 set_file_handler_level = set_handler_level(logging.FileHandler)
 
 
-def set_logger_level(level: int or str) -> None:
+def set_logger_level(level: Union[int, str]) -> None:
     try:
-        level = level.upper()
+        level = level.upper() # type: ignore
     except AttributeError:
         pass
     logger.setLevel(level)
