@@ -28,7 +28,7 @@ from abc import ABC, abstractmethod
 from collections import defaultdict
 from concurrent.futures import ThreadPoolExecutor
 from pathlib import Path
-from typing import Dict, Callable, List, Any, Tuple, Pattern
+from typing import Dict, Callable, Generator, Iterator, List, Any, Optional, Tuple, Pattern, Union
 
 import bs4
 import ujson
@@ -133,55 +133,55 @@ class Corpus(ABC):
     DATA_FOLDER = Path('data')
 
     def __init__(self,
-                 query: dict or str = None,
-                 p_count: int = None,
-                 file: str or Path = None,
+                 query: Optional[Union[dict, str]] = None,
+                 p_count: Optional[int] = None,
+                 file: Optional[Union[str, Path]] = None,
                  **kwargs) -> None:
-        """ 
-        If the file exists, working with a local database.
+        """
+         If the file exists, working with a local database.
 
-        :param query: dict of str, words to search;
+         :param query: dict of str, words to search;
          {word1: {properties}, word2: {properties}...}.
          If you chose 'lexform' as a 'text' param, you must give here a string.
-        :param p_count: int, count of pages to request.
-        :param file: str or Path, filename of a local database.
+         :param p_count: int, count of pages to request.
+         :param file: str or Path, filename of a local database.
          Optional, random filename by default.
-        :keyword dpp: str or int, documents per page.
+         :keyword dpp: str or int, documents per page.
          Optional, 5 by default.
-        :keyword spd: str or int, sentences per document.
+         :keyword spd: str or int, sentences per document.
          Optional, 10 by default.
-        :keyword text: str, search format: 'lexgramm' or 'lexform'.
+         :keyword text: str, search format: 'lexgramm' or 'lexform'.
          Optional, 'lexgramm' by default.
-        :keyword out: str, output format: 'normal' or 'kwic'.
+         :keyword out: str, output format: 'normal' or 'kwic'.
          Optional, 'normal' bu default.
-        :keyword kwsz: str or int, count of words in context;
+         :keyword kwsz: str or int, count of words in context;
          Optional param if 'out' is 'kwic'.
-        :keyword sort: str, sort show order. See docs how to set it.
+         :keyword sort: str, sort show order. See docs how to set it.
          Optional.
-        :keyword mycorp: str, mycorp. This is way to specify the sample of docs
+         :keyword mycorp: This is way to specify the sample of docs
          where you want to find sth. See docs how to set it. Optional.
-        :keyword expand: str, if 'full', all part of doc will be shown. 
+         :keyword expand: str, if 'full', all part of doc will be shown.
          Now it doesn't work.
-        :keyword accent: str or int, with accents on words or not:
+         :keyword accent: str or int, with accents on words or not:
          1 – with, 0 – without. Optional, 0 by default.
-        :keyword marker: function, with which found words will be marked.
+         :keyword marker: function, with which found words will be marked.
          Optional.
 
-        :exception FileExistsError: if csv file is given but json file
+         :exception FileExistsError: if csv file is given but json file
          with config doesn't exist.
-        :exception ValueError: if the query is empty; page count is a negative 
+         :exception ValueError: if the query is empty; page count is a negative
          number; text, out or sort key is wrong.
-        :exception NotImplementedError: if the corpus type in file isn't equal 
+         :exception NotImplementedError: if the corpus type in file isn't equal
          to corpus class type.
-        """
+         """
         # list of examples
-        self._data = []
+        self._data: List[expl.Example] = []
         # http tags to request
-        self._params = {}
+        self._params: Dict[str, Any] = {}
         # found wordforms with their frequency
-        self._found_wordforms = defaultdict(int)
+        self._found_wordforms: Dict[str, int] = defaultdict(int)
         # query, wordforms to find
-        self._query = {}
+        self._query: Dict[str, Any] = {}
         # count of PAGES
         self._p_count = 0
         # type of example should be defined before params init
@@ -190,12 +190,12 @@ class Corpus(ABC):
         # additional info from the first page:
         # amount of docs, contexts, where the query was found,
         # link to the graphic with distribution by years
-        self._add_info = {}
+        self._add_info: Dict[str, Any] = {}
 
         # path to local database
         class_name = self.__class__.__name__.replace('Corpus', '')
         path = file or create_unique_filename(
-            self.DATA_FOLDER, class_name, p_count)
+            self.DATA_FOLDER, class_name, p_count) # type: ignore
         path = Path(path)
         # change or add right extension
         path = path.with_suffix('.csv')
@@ -214,10 +214,10 @@ class Corpus(ABC):
                 raise
         # or work with RNC
         else:
-            self._from_corpus(query, p_count, **kwargs)
+            self._from_corpus(query, p_count, **kwargs) # type: ignore
 
     def _from_corpus(self,
-                     query: dict or str,
+                     query: Union[Dict[str, Any], str],
                      p_count: int,
                      **kwargs) -> None:
         """ Set given values to the object. If the file does not exist.
@@ -230,7 +230,7 @@ class Corpus(ABC):
             msg = f"Query must be not empty, but '{query}' found"
             logger.error(msg)
             raise ValueError(msg)
-        self._query = query
+        self._query = query # type: ignore
 
         if p_count <= 0:
             msg = f"Pages count must be > 0, but '{p_count}' found"
@@ -327,7 +327,8 @@ class Corpus(ABC):
             next(reader)
 
             data = [self.ex_type(*row) for row in reader]
-            wordforms = list(map(lambda example: example.found_wordforms, data))
+            wordforms = list(map(lambda example: example.found_wordforms,
+                                 data))
             wordforms = sum(wordforms, [])
             self._add_wordforms(wordforms)
 
@@ -398,7 +399,7 @@ class Corpus(ABC):
         cls.__MAX = value
 
     @classmethod
-    def set_restrict_show(cls, value: int or bool) -> None:
+    def set_restrict_show(cls, value: Union[int, bool]) -> None:
         """ Set amount of showing examples.
         Show all examples if `False` given.
         """
@@ -466,7 +467,7 @@ class Corpus(ABC):
         return src
 
     @staticmethod
-    def _parse_lexgramm_params(params: dict or str,
+    def _parse_lexgramm_params(params: Union[dict, str],
                                join_inside_symbol: str,
                                with_braces: bool = False) -> str:
         """ Convert lexgramm params to str for HTTP request.
@@ -512,8 +513,7 @@ class Corpus(ABC):
         return [
             tag.text.strip()
             for tag in tag.contents
-            if (isinstance(tag, bs4.element.Tag) and
-                'g-em' in tag.attrs.get('class', ''))
+            if (isinstance(tag, bs4.element.Tag) and 'g-em' in tag.attrs.get('class', ''))
         ]
 
     @property
@@ -522,7 +522,7 @@ class Corpus(ABC):
         return self._data
 
     @property
-    def query(self) -> Dict[str, dict] or str:
+    def query(self) -> Union[Dict[str, dict], str]:
         """ Get requested words items (dict of words
         with params or str with words)
         """
@@ -576,21 +576,21 @@ class Corpus(ABC):
         return self._ex_type
 
     @property
-    def amount_of_docs(self) -> int or None:
+    def amount_of_docs(self) -> Optional[int]:
         """ Get amount of documents, where the query was found
         or None if there's no this info.
         """
         return self._add_info.get('docs', None)
 
     @property
-    def amount_of_contexts(self) -> int or None:
+    def amount_of_contexts(self) -> Optional[int]:
         """ Get amount of contexts, where the query was found
         or None if there's no this info.
         """
         return self._add_info.get('contexts', None)
 
     @property
-    def graphic_link(self) -> str or None:
+    def graphic_link(self) -> Optional[str]:
         """ Get the link to the graphic
         or None if there's no this info.
         """
@@ -611,17 +611,17 @@ class Corpus(ABC):
         return res
 
     @staticmethod
-    def _get_graphic_url(content: bs4.element.Tag) -> str or None:
+    def _get_graphic_url(content: bs4.element.Tag) -> Optional[str]:
         """ Get URL to the graphic. """
         a = content.find('a', {'target': '_blank'})
         try:
             link = a['href']
         except (KeyError, TypeError, AttributeError):
-            return
+            return # type: ignore
         return f"{BASE_RNC_URL}/{link}"
 
     def _get_additional_info(self,
-                             first_page: str = None) -> None:
+                             first_page: Optional[str] = None) -> None:
         """ Get additional info (amount of found
         docs and contexts, link to the graphic).
         """
@@ -649,7 +649,7 @@ class Corpus(ABC):
             self._add_info = additional_info
 
     async def _get_additional_info_async(self,
-                                         first_page: str = None) -> None:
+                                         first_page: Optional[str] = None) -> None:
         """ Get additional info (amount of found
         docs and contexts, link to the graphic).
         """
@@ -657,8 +657,7 @@ class Corpus(ABC):
         params['lang'] = 'ru'
         params.pop('expand', None)
         try:
-            first_page = first_page or \
-                         (await creq.get_htmls_async(RNC_URL, **params))[0]
+            first_page = first_page or (await creq.get_htmls_async(RNC_URL, **params))[0]
         except creq.BaseRequestError:
             raise
 
@@ -683,9 +682,9 @@ class Corpus(ABC):
         """
         if self.out == 'normal':
             # ex_type is defined above in this case
-            self._page_parser = self._parse_page_normal
+            self._page_parser = self._parse_page_normal # type: ignore
         elif self.out == 'kwic':
-            self._page_parser = self._parse_page_kwic
+            self._page_parser = self._parse_page_kwic # type: ignore
             self._ex_type = expl.KwicExample
 
     def _query_to_http(self) -> None:
@@ -742,7 +741,8 @@ class Corpus(ABC):
             gramm = params.pop('gramm', '')
             if gramm:
                 try:
-                    gram_props = Corpus._parse_lexgramm_params(gramm, '|', True)
+                    gram_props = Corpus._parse_lexgramm_params(
+                        gramm, '|', True)
                 except Exception:
                     raise
                 self._params[f"gramm{word_num}"] = gram_props
@@ -873,7 +873,7 @@ class Corpus(ABC):
                          pages: List[str]) -> List:
         """ Parse all pages. """
         parsed = [
-            self._page_parser(page)
+            self._page_parser(page) # type: ignore
             for page in pages
         ]
         return sum(parsed, [])
@@ -1060,7 +1060,8 @@ class Corpus(ABC):
                   **kwargs) -> None:
         """ Sort the data by using a key.
 
-        :keyword key: func to sort, called to Example objects, by default – len.
+        :keyword key: func to sort, called to Example objects,
+        by default – len.
         :keyword reverse: bool, whether the data will sort in reversed order,
          by default – False.
 
@@ -1099,8 +1100,8 @@ class Corpus(ABC):
         self._data = filtered_data[:]
 
     def findall(self,
-                pattern: Pattern or str,
-                *args) -> Tuple[expl.Example, List[str]]:
+                pattern: Union[Pattern, str],
+                *args) -> Generator[Tuple[expl.Example, List[str]], None, None]:
         """ Apply the pattern to the examples' text with re.findall.
         Yield all examples which are satisfy the pattern and match.
         """
@@ -1110,8 +1111,8 @@ class Corpus(ABC):
                 yield example, match
 
     def finditer(self,
-                 pattern: Pattern or str,
-                 *args) -> Tuple[expl.Example, Any]:
+                 pattern: Union[Pattern, str],
+                 *args) -> Generator[Tuple[expl.Example, Any], None, None]:
         """ Apply the pattern to the examples' text with re.finditer.
         Yield all examples which are satisfy the pattern and match.
         """
@@ -1170,7 +1171,7 @@ class Corpus(ABC):
         """ All the same to request_examples() """
         self.request_examples()
 
-    def __iter__(self) -> iter:
+    def __iter__(self) -> Iterator:
         return iter(self.data)
 
     def __contains__(self,
@@ -1192,7 +1193,7 @@ class Corpus(ABC):
         )
 
     def __getattr__(self,
-                    item: str) -> str or int or List or None:
+                    item: str) -> Optional[Union[str, int, List]]:
         """ Get request param.
 
         :return: param value or None if it does not exist.
@@ -1203,7 +1204,7 @@ class Corpus(ABC):
             return self.params.get(item, None)
 
     def __getitem__(self,
-                    item: int or slice) -> Any:
+                    item: Union[int, slice]) -> Any:
         r""" Get example from data or create
          new obj with sliced data.
 
@@ -1256,7 +1257,7 @@ class Corpus(ABC):
             raise
 
     def __delitem__(self,
-                    key: int or slice) -> None:
+                    key: Union[int, slice]) -> None:
         """ Delete example at the index or
          remove several ones using slice.
 
@@ -1287,8 +1288,8 @@ class MainCorpus(Corpus):
         super().__init__(*args, **kwargs, ex_type=ex_type)
         self._params['mode'] = self._MODE
 
-    def _parse_example(self,
-                       example: bs4.element.Tag):
+    def _parse_example(self, # type: ignore
+                       example: bs4.element.Tag) -> expl.Example:
         """ Parse example to Example object. """
         src = Corpus._get_source(example)
         txt = Corpus._get_text(example)
@@ -1312,7 +1313,7 @@ class MainCorpus(Corpus):
         res = []
 
         for example in doc.find_all('li'):
-            new_ex = self._parse_example(example)
+            new_ex: expl.MainExample = self._parse_example(example) # type: ignore
             res += [new_ex]
             self._add_wordforms(new_ex.found_wordforms)
         return res
@@ -1392,8 +1393,8 @@ class ParallelCorpus(Corpus):
         new_txt.mark_found_words(self.marker)
         return new_txt
 
-    def _parse_example(self,
-                       tag: bs4.element.Tag) -> Any:
+    def _parse_example(self, # type: ignore
+                       tag: bs4.element.Tag) -> expl.Example:
         """ Parse a pair: original – translation to Example. """
         # this example is expected to have default args
         result_example = self.ex_type()
@@ -1515,9 +1516,9 @@ class MultimodalCorpus(Corpus):
         super().__init__(*args, **kwargs, ex_type=expl.MultimodalExample)
         self._params['mode'] = self._MODE
 
-    def _parse_example(self,
-                       example: bs4.element.Tag) -> Tuple[
-        str, str, str, list, str]:
+    def _parse_example(self, # type: ignore
+                       example: bs4.element.Tag
+                       ) -> Tuple[str, str, str, list, str]:
         """ Parse example get text, source etc. """
         src = Corpus._get_source(example)
         txt = Corpus._get_text(example)
